"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImportWorkflowsCommand = void 0;
const command_1 = require("@oclif/command");
const src_1 = require("../../src");
const fs = require("fs");
const glob = require("glob-promise");
const path = require("path");
class ImportWorkflowsCommand extends command_1.Command {
    async run() {
        const { flags } = this.parse(ImportWorkflowsCommand);
        if (!flags.input) {
            src_1.GenericHelpers.logOutput(`An input file or directory with --input must be provided`);
            return;
        }
        if (flags.separate) {
            if (fs.existsSync(flags.input)) {
                if (!fs.lstatSync(flags.input).isDirectory()) {
                    src_1.GenericHelpers.logOutput(`The paramenter --input must be a directory`);
                    return;
                }
            }
        }
        try {
            await src_1.Db.init();
            let i;
            if (flags.separate) {
                const files = await glob((flags.input.endsWith(path.sep) ? flags.input : flags.input + path.sep) + '*.json');
                for (i = 0; i < files.length; i++) {
                    const workflow = JSON.parse(fs.readFileSync(files[i], { encoding: 'utf8' }));
                    await src_1.Db.collections.Workflow.save(workflow);
                }
            }
            else {
                const fileContents = JSON.parse(fs.readFileSync(flags.input, { encoding: 'utf8' }));
                if (!Array.isArray(fileContents)) {
                    throw new Error(`File does not seem to contain workflows.`);
                }
                for (i = 0; i < fileContents.length; i++) {
                    await src_1.Db.collections.Workflow.save(fileContents[i]);
                }
            }
            console.log('Successfully imported', i, i === 1 ? 'workflow.' : 'workflows.');
        }
        catch (error) {
            this.error(error.message);
            this.exit(1);
        }
    }
}
exports.ImportWorkflowsCommand = ImportWorkflowsCommand;
ImportWorkflowsCommand.description = 'Import workflows';
ImportWorkflowsCommand.examples = [
    `$ n8n import:workflow --input=file.json`,
    `$ n8n import:workflow --separate --input=backups/latest/`,
];
ImportWorkflowsCommand.flags = {
    help: command_1.flags.help({ char: 'h' }),
    input: command_1.flags.string({
        char: 'i',
        description: 'Input file name or directory if --separate is used',
    }),
    separate: command_1.flags.boolean({
        description: 'Imports *.json files from directory provided by --input',
    }),
};
//# sourceMappingURL=workflow.js.map