"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UpdateWorkflowCommand = void 0;
const command_1 = require("@oclif/command");
const src_1 = require("../../src");
class UpdateWorkflowCommand extends command_1.Command {
    async run() {
        const { flags } = this.parse(UpdateWorkflowCommand);
        if (!flags.all && !flags.id) {
            src_1.GenericHelpers.logOutput(`Either option "--all" or "--id" have to be set!`);
            return;
        }
        if (flags.all && flags.id) {
            src_1.GenericHelpers.logOutput(`Either something else on top should be "--all" or "--id" can be set never both!`);
            return;
        }
        const updateQuery = {};
        if (flags.active === undefined) {
            src_1.GenericHelpers.logOutput(`No update flag like "--active=true" has been set!`);
            return;
        }
        else {
            if (!['false', 'true'].includes(flags.active)) {
                src_1.GenericHelpers.logOutput(`Valid values for flag "--active" are only "false" or "true"!`);
                return;
            }
            updateQuery.active = flags.active === 'true';
        }
        try {
            await src_1.Db.init();
            const findQuery = {};
            if (flags.id) {
                console.log(`Deactivating workflow with ID: ${flags.id}`);
                findQuery.id = flags.id;
            }
            else {
                console.log('Deactivating all workflows');
                findQuery.active = true;
            }
            await src_1.Db.collections.Workflow.update(findQuery, updateQuery);
            console.log('Done');
        }
        catch (e) {
            console.error('\nGOT ERROR');
            console.log('====================================');
            console.error(e.message);
            console.error(e.stack);
            this.exit(1);
        }
        this.exit();
    }
}
exports.UpdateWorkflowCommand = UpdateWorkflowCommand;
UpdateWorkflowCommand.description = '\Update workflows';
UpdateWorkflowCommand.examples = [
    `$ n8n update:workflow --all --active=false`,
    `$ n8n update:workflow --id=5 --active=true`,
];
UpdateWorkflowCommand.flags = {
    help: command_1.flags.help({ char: 'h' }),
    active: command_1.flags.string({
        description: 'Active state the workflow/s should be set to',
    }),
    all: command_1.flags.boolean({
        description: 'Operate on all workflows',
    }),
    id: command_1.flags.string({
        description: 'The ID of the workflow to operate on',
    }),
};
//# sourceMappingURL=workflow.js.map