"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInstance = exports.Push = void 0;
const sseChannel = require("sse-channel");
class Push {
    constructor() {
        this.connections = {};
        this.channel = new sseChannel({
            cors: {
                origins: ['http://localhost:8080'],
            },
        });
        this.channel.on('disconnect', (channel, res) => {
            if (res.req !== undefined) {
                delete this.connections[res.req.query.sessionId];
            }
        });
    }
    add(sessionId, req, res) {
        if (this.connections[sessionId] !== undefined) {
            this.connections[sessionId].end();
            this.channel.removeClient(this.connections[sessionId]);
        }
        this.connections[sessionId] = res;
        this.channel.addClient(req, res);
    }
    send(type, data, sessionId) {
        if (sessionId !== undefined && this.connections[sessionId] === undefined) {
            console.error(`The session "${sessionId}" is not registred.`);
            return;
        }
        const sendData = {
            type,
            data,
        };
        if (sessionId === undefined) {
            this.channel.send(JSON.stringify(sendData));
        }
        else {
            this.channel.send(JSON.stringify(sendData), [this.connections[sessionId]]);
        }
    }
}
exports.Push = Push;
let activePushInstance;
function getInstance() {
    if (activePushInstance === undefined) {
        activePushInstance = new Push();
    }
    return activePushInstance;
}
exports.getInstance = getInstance;
//# sourceMappingURL=Push.js.map