"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.activeCampaignDefaultGetAllProperties = exports.activeCampaignApiRequestAllItems = exports.activeCampaignApiRequest = void 0;
async function activeCampaignApiRequest(method, endpoint, body, query, dataKey) {
    const credentials = this.getCredentials('activeCampaignApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    if (query === undefined) {
        query = {};
    }
    const options = {
        headers: {
            'Api-Token': credentials.apiKey,
        },
        method,
        qs: query,
        uri: `${credentials.apiUrl}${endpoint}`,
        json: true,
    };
    if (Object.keys(body).length !== 0) {
        options.body = body;
    }
    try {
        const responseData = await this.helpers.request(options);
        if (responseData.success === false) {
            throw new Error(`ActiveCampaign error response: ${responseData.error} (${responseData.error_info})`);
        }
        if (dataKey === undefined) {
            return responseData;
        }
        else {
            return responseData[dataKey];
        }
    }
    catch (error) {
        if (error.statusCode === 403) {
            throw new Error('The ActiveCampaign credentials are not valid!');
        }
        throw error;
    }
}
exports.activeCampaignApiRequest = activeCampaignApiRequest;
async function activeCampaignApiRequestAllItems(method, endpoint, body, query, dataKey) {
    if (query === undefined) {
        query = {};
    }
    query.limit = 100;
    query.offset = 0;
    const returnData = [];
    let responseData;
    let itemsReceived = 0;
    do {
        responseData = await activeCampaignApiRequest.call(this, method, endpoint, body, query);
        if (dataKey === undefined) {
            returnData.push.apply(returnData, responseData);
            if (returnData !== undefined) {
                itemsReceived += returnData.length;
            }
        }
        else {
            returnData.push.apply(returnData, responseData[dataKey]);
            if (responseData[dataKey] !== undefined) {
                itemsReceived += responseData[dataKey].length;
            }
        }
        query.offset = itemsReceived;
    } while (responseData.meta !== undefined &&
        responseData.meta.total !== undefined &&
        responseData.meta.total > itemsReceived);
    return returnData;
}
exports.activeCampaignApiRequestAllItems = activeCampaignApiRequestAllItems;
function activeCampaignDefaultGetAllProperties(resource, operation) {
    return [
        {
            displayName: 'Return All',
            name: 'returnAll',
            type: 'boolean',
            displayOptions: {
                show: {
                    operation: [
                        operation,
                    ],
                    resource: [
                        resource,
                    ],
                },
            },
            default: false,
            description: 'If all results should be returned or only up to a given limit.',
        },
        {
            displayName: 'Limit',
            name: 'limit',
            type: 'number',
            displayOptions: {
                show: {
                    operation: [
                        operation,
                    ],
                    resource: [
                        resource,
                    ],
                    returnAll: [
                        false,
                    ],
                },
            },
            typeOptions: {
                minValue: 1,
                maxValue: 500,
            },
            default: 100,
            description: 'How many results to return.',
        },
        {
            displayName: 'Simple',
            name: 'simple',
            type: 'boolean',
            displayOptions: {
                show: {
                    operation: [
                        operation,
                    ],
                    resource: [
                        resource,
                    ],
                },
            },
            default: true,
            description: 'When set to true a simplify version of the response will be used else the raw data.',
        },
    ];
}
exports.activeCampaignDefaultGetAllProperties = activeCampaignDefaultGetAllProperties;
//# sourceMappingURL=GenericFunctions.js.map