"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.keysToSnakeCase = exports.bannerbearApiRequest = void 0;
const change_case_1 = require("change-case");
async function bannerbearApiRequest(method, resource, body = {}, query = {}, uri, headers = {}) {
    const credentials = this.getCredentials('bannerbearApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const options = {
        headers: {
            Accept: 'application/json',
            Authorization: `Bearer ${credentials.apiKey}`,
        },
        method,
        body,
        qs: query,
        uri: uri || `https://api.bannerbear.com/v2${resource}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.form;
    }
    if (!Object.keys(query).length) {
        delete options.qs;
    }
    options.headers = Object.assign({}, options.headers, headers);
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            throw new Error(`Bannerbear error response [${error.statusCode}]: ${error.response.body.message}`);
        }
        throw error;
    }
}
exports.bannerbearApiRequest = bannerbearApiRequest;
function keysToSnakeCase(elements) {
    if (!Array.isArray(elements)) {
        elements = [elements];
    }
    for (const element of elements) {
        for (const key of Object.keys(element)) {
            if (key !== change_case_1.snakeCase(key)) {
                element[change_case_1.snakeCase(key)] = element[key];
                delete element[key];
            }
        }
    }
    return elements;
}
exports.keysToSnakeCase = keysToSnakeCase;
//# sourceMappingURL=GenericFunctions.js.map