"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.beeminderApiRequestAllItems = exports.beeminderApiRequest = void 0;
const BEEMINDER_URI = 'https://www.beeminder.com/api/v1';
async function beeminderApiRequest(method, endpoint, body = {}, query = {}) {
    const credentials = this.getCredentials('beeminderApi');
    Object.assign(body, { auth_token: credentials.authToken });
    const options = {
        method,
        body,
        qs: query,
        uri: `${BEEMINDER_URI}${endpoint}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.body;
    }
    if (!Object.keys(query).length) {
        delete options.qs;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error === null || error === void 0 ? void 0 : error.message) {
            throw new Error(`Beeminder error response [${error.statusCode}]: ${error.message}`);
        }
        throw error;
    }
}
exports.beeminderApiRequest = beeminderApiRequest;
async function beeminderApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.page = 1;
    do {
        responseData = await beeminderApiRequest.call(this, method, endpoint, body, query);
        query.page++;
        returnData.push.apply(returnData, responseData);
    } while (responseData.length !== 0);
    return returnData;
}
exports.beeminderApiRequestAllItems = beeminderApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map