"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.brandfetchApiRequest = void 0;
async function brandfetchApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    try {
        const credentials = this.getCredentials('brandfetchApi');
        if (credentials === undefined) {
            throw new Error('No credentials got returned!');
        }
        let options = {
            headers: {
                'x-api-key': credentials.apiKey,
            },
            method,
            qs,
            body,
            uri: uri || `https://api.brandfetch.io/v1${resource}`,
            json: true,
        };
        options = Object.assign({}, options, option);
        if (this.getNodeParameter('operation', 0) === 'logo' && options.json === false) {
            delete options.headers;
        }
        if (!Object.keys(body).length) {
            delete options.body;
        }
        if (!Object.keys(qs).length) {
            delete options.qs;
        }
        const response = await this.helpers.request(options);
        if (response.statusCode && response.statusCode !== 200) {
            throw new Error(`Brandfetch error response [${response.statusCode}]: ${response.response}`);
        }
        return response;
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            const errorBody = error.response.body;
            throw new Error(`Brandfetch error response [${error.statusCode}]: ${errorBody.message}`);
        }
        throw error;
    }
}
exports.brandfetchApiRequest = brandfetchApiRequest;
//# sourceMappingURL=GenericFunctions.js.map