"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tagSubscriberFields = exports.tagSubscriberOperations = void 0;
exports.tagSubscriberOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        displayOptions: {
            show: {
                resource: [
                    'tagSubscriber',
                ],
            },
        },
        options: [
            {
                name: 'Add',
                value: 'add',
                description: 'Add a tag to a subscriber',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'List subscriptions to a tag including subscriber data',
            },
            {
                name: 'Delete',
                value: 'delete',
                description: 'Delete a tag from a subscriber',
            },
        ],
        default: 'create',
        description: 'The operation to perform.',
    },
];
exports.tagSubscriberFields = [
    {
        displayName: 'Tag ID',
        name: 'tagId',
        type: 'options',
        typeOptions: {
            loadOptionsMethod: 'getTags',
        },
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'tagSubscriber',
                ],
                operation: [
                    'add',
                    'getAll',
                    'delete',
                ],
            },
        },
        default: '',
    },
    {
        displayName: 'Email',
        name: 'email',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'tagSubscriber',
                ],
                operation: [
                    'add',
                    'delete',
                ],
            },
        },
        default: '',
        description: 'Subscriber email address.',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                resource: [
                    'tagSubscriber',
                ],
                operation: [
                    'add',
                ],
            },
        },
        options: [
            {
                displayName: 'Custom Fields',
                name: 'fields',
                placeholder: 'Add Custom Field',
                description: 'Object of key/value pairs for custom fields (the custom field must exist before you can use it here).',
                type: 'fixedCollection',
                typeOptions: {
                    multipleValues: true,
                },
                default: {},
                options: [
                    {
                        name: 'field',
                        displayName: 'Custom Field',
                        values: [
                            {
                                displayName: 'Field Key',
                                name: 'key',
                                type: 'string',
                                default: '',
                                placeholder: 'last_name',
                                description: `The field's key.`,
                            },
                            {
                                displayName: 'Field Value',
                                name: 'value',
                                type: 'string',
                                default: '',
                                placeholder: 'Doe',
                                description: 'Value of the field.',
                            },
                        ],
                    },
                ],
            },
            {
                displayName: 'First Name',
                name: 'firstName',
                type: 'string',
                default: '',
                description: 'Subscriber first name.',
            },
        ],
    },
    {
        displayName: 'Return All',
        name: 'returnAll',
        type: 'boolean',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'tagSubscriber',
                ],
            },
        },
        default: false,
        description: 'If all results should be returned or only up to a given limit.',
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'tagSubscriber',
                ],
                returnAll: [
                    false,
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 500,
        },
        default: 100,
        description: 'How many results to return.',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                resource: [
                    'tagSubscriber',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        options: [
            {
                displayName: 'Subscriber State',
                name: 'subscriberState',
                type: 'options',
                options: [
                    {
                        name: 'Active',
                        value: 'active',
                    },
                    {
                        name: 'Cancelled',
                        value: 'cancelled',
                    },
                ],
                default: 'active',
            },
        ],
        description: 'Receive only active subscribers or cancelled subscribers.',
    },
];
//# sourceMappingURL=TagSubscriberDescription.js.map