"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAutomaticSecret = exports.copperApiRequest = void 0;
const crypto_1 = require("crypto");
async function copperApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('copperApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    let options = {
        headers: {
            'X-PW-AccessToken': credentials.apiKey,
            'X-PW-Application': 'developer_api',
            'X-PW-UserEmail': credentials.email,
            'Content-Type': 'application/json',
        },
        method,
        qs,
        body,
        uri: uri || `https://api.prosperworks.com/developer_api/v1${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.response.body && error.response.body.message) {
            errorMessage = error.response.body.message;
        }
        throw new Error('Copper Error: ' + errorMessage);
    }
}
exports.copperApiRequest = copperApiRequest;
function getAutomaticSecret(credentials) {
    const data = `${credentials.email},${credentials.apiKey}`;
    return crypto_1.createHash('md5').update(data).digest('hex');
}
exports.getAutomaticSecret = getAutomaticSecret;
//# sourceMappingURL=GenericFunctions.js.map