"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.eventExists = exports.customerIoApiRequest = void 0;
const lodash_1 = require("lodash");
async function customerIoApiRequest(method, endpoint, body, baseApi, query) {
    const credentials = this.getCredentials('customerIoApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    query = query || {};
    const options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body,
        uri: '',
        json: true,
    };
    if (baseApi === 'tracking') {
        options.uri = `https://track.customer.io/api/v1${endpoint}`;
        const basicAuthKey = Buffer.from(`${credentials.trackingSiteId}:${credentials.trackingApiKey}`).toString('base64');
        Object.assign(options.headers, { 'Authorization': `Basic ${basicAuthKey}` });
    }
    else if (baseApi === 'api') {
        options.uri = `https://api.customer.io/v1/api${endpoint}`;
        const basicAuthKey = Buffer.from(`${credentials.trackingSiteId}:${credentials.trackingApiKey}`).toString('base64');
        Object.assign(options.headers, { 'Authorization': `Basic ${basicAuthKey}` });
    }
    else if (baseApi === 'beta') {
        options.uri = `https://beta-api.customer.io/v1/api${endpoint}`;
        Object.assign(options.headers, { 'Authorization': `Bearer ${credentials.appApiKey}` });
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Customer.io credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.error_code) {
            const errorBody = error.response.body;
            throw new Error(`Customer.io error response [${errorBody.error_code}]: ${errorBody.description}`);
        }
        throw error;
    }
}
exports.customerIoApiRequest = customerIoApiRequest;
function eventExists(currentEvents, webhookEvents) {
    for (const currentEvent of currentEvents) {
        if (lodash_1.get(webhookEvents, `${currentEvent.split('.')[0]}.${currentEvent.split('.')[1]}`) !== true) {
            return false;
        }
    }
    return true;
}
exports.eventExists = eventExists;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map