"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.discourseApiRequestAllItems = exports.discourseApiRequest = void 0;
async function discourseApiRequest(method, path, body = {}, qs = {}, option = {}) {
    const credentials = this.getCredentials('discourseApi');
    const options = {
        headers: {
            'Api-Key': credentials.apiKey,
            'Api-Username': credentials.username,
        },
        method,
        body,
        qs,
        uri: `${credentials.url}${path}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.request.call(this, options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.errors) {
            const errors = error.response.body.errors;
            throw new Error(`Discourse error response [${error.statusCode}]: ${errors.join('|')}`);
        }
        throw error;
    }
}
exports.discourseApiRequest = discourseApiRequest;
async function discourseApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.page = 1;
    do {
        responseData = await discourseApiRequest.call(this, method, endpoint, body, query);
        returnData.push.apply(returnData, responseData);
        query.page++;
    } while (responseData.length !== 0);
    return returnData;
}
exports.discourseApiRequestAllItems = discourseApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map