"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userFields = exports.userOperations = void 0;
exports.userOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        description: 'Choose an operation',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: 'Create a user',
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Get a user',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'Get all users',
            },
        ],
        default: 'create',
    },
];
exports.userFields = [
    {
        displayName: 'Name',
        name: 'name',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'create',
                ],
            },
        },
        default: '',
        description: 'Name of the user to create.',
    },
    {
        displayName: 'Email',
        name: 'email',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'create',
                ],
            },
        },
        default: '',
        description: 'Email of the user to create.',
    },
    {
        displayName: 'Username',
        name: 'username',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'create',
                ],
            },
        },
        default: '',
        description: `The username of the user to create.`,
    },
    {
        displayName: 'Password',
        name: 'password',
        type: 'string',
        typeOptions: {
            password: true,
        },
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'create',
                ],
            },
        },
        default: '',
        description: `The password of the user to create.`,
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'create',
                ],
            },
        },
        options: [
            {
                displayName: 'Active',
                name: 'active',
                type: 'boolean',
                default: false,
            },
            {
                displayName: 'Approved',
                name: 'approved',
                type: 'boolean',
                default: false,
            },
        ],
    },
    {
        displayName: 'By',
        name: 'by',
        type: 'options',
        options: [
            {
                name: 'Username',
                value: 'username',
            },
            {
                name: 'SSO External ID',
                value: 'externalId',
            },
        ],
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'get',
                ],
            },
        },
        default: 'username',
        description: 'What to search by.',
    },
    {
        displayName: 'Username',
        name: 'username',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'get',
                ],
                by: [
                    'username',
                ],
            },
        },
        default: '',
        description: `The username of the user to return.`,
    },
    {
        displayName: 'SSO External ID',
        name: 'externalId',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'get',
                ],
                by: [
                    'externalId',
                ],
            },
        },
        default: '',
        description: `Discourse SSO external ID.`,
    },
    {
        displayName: 'Flag',
        name: 'flag',
        type: 'options',
        options: [
            {
                name: 'Active',
                value: 'active',
            },
            {
                name: 'Blocked',
                value: 'blocked',
            },
            {
                name: 'New',
                value: 'new',
            },
            {
                name: 'Staff',
                value: 'staff',
            },
            {
                name: 'Suspect',
                value: 'suspect',
            },
        ],
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        default: '',
        description: `User flags to search for.`,
    },
    {
        displayName: 'Return All',
        name: 'returnAll',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        default: false,
        description: 'If all results should be returned or only up to a given limit.',
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                resource: [
                    'user',
                ],
                operation: [
                    'getAll',
                ],
                returnAll: [
                    false,
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 100,
        },
        default: 50,
        description: 'How many results to return.',
    },
];
//# sourceMappingURL=UserDescription.js.map