"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dropboxApiRequest = void 0;
async function dropboxApiRequest(method, endpoint, body, query = {}, headers, option = {}) {
    const options = {
        headers,
        method,
        qs: query,
        body,
        uri: endpoint,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.body;
    }
    Object.assign(options, option);
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    try {
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('dropboxApi');
            options.headers['Authorization'] = `Bearer ${credentials.accessToken}`;
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'dropboxOAuth2Api', options);
        }
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Dropbox credentials are not valid!');
        }
        if (error.error && error.error.error_summary) {
            throw new Error(`Dropbox error response [${error.statusCode}]: ${error.error.error_summary}`);
        }
        throw error;
    }
}
exports.dropboxApiRequest = dropboxApiRequest;
//# sourceMappingURL=GenericFunctions.js.map