"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Function = void 0;
const { NodeVM } = require('vm2');
class Function {
    constructor() {
        this.description = {
            displayName: 'Function',
            name: 'function',
            icon: 'fa:code',
            group: ['transform'],
            version: 1,
            description: 'Run custom function code which gets executed once and allows to add, remove, change and replace items.',
            defaults: {
                name: 'Function',
                color: '#FF9922',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'JavaScript Code',
                    name: 'functionCode',
                    typeOptions: {
                        alwaysOpenEditWindow: true,
                        editor: 'code',
                        rows: 10,
                    },
                    type: 'string',
                    default: 'items[0].json.myVariable = 1;\nreturn items;',
                    description: 'The JavaScript code to execute.',
                    noDataExpression: true,
                },
            ],
        };
    }
    async execute() {
        let items = this.getInputData();
        items = JSON.parse(JSON.stringify(items));
        const sandbox = {
            getNodeParameter: this.getNodeParameter,
            getWorkflowStaticData: this.getWorkflowStaticData,
            helpers: this.helpers,
            items,
            $item: (index) => this.getWorkflowDataProxy(index),
        };
        Object.assign(sandbox, sandbox.$item(0));
        const options = {
            console: 'inherit',
            sandbox,
            require: {
                external: false,
                builtin: [],
            },
        };
        if (process.env.NODE_FUNCTION_ALLOW_BUILTIN) {
            options.require.builtin = process.env.NODE_FUNCTION_ALLOW_BUILTIN.split(',');
        }
        if (process.env.NODE_FUNCTION_ALLOW_EXTERNAL) {
            options.require.external = { modules: process.env.NODE_FUNCTION_ALLOW_EXTERNAL.split(',') };
        }
        const vm = new NodeVM(options);
        const functionCode = this.getNodeParameter('functionCode', 0);
        try {
            items = (await vm.run(`module.exports = async function() {${functionCode}}()`, __dirname));
        }
        catch (e) {
            return Promise.reject(e);
        }
        if (items === undefined) {
            throw new Error('No data got returned. Always return an Array of items!');
        }
        if (!Array.isArray(items)) {
            throw new Error('Always an Array of items has to be returned!');
        }
        for (const item of items) {
            if (item.json === undefined) {
                throw new Error('All returned items have to contain a property named "json"!');
            }
            if (typeof item.json !== 'object') {
                throw new Error('The json-property has to be an object!');
            }
            if (item.binary !== undefined) {
                if (Array.isArray(item.binary) || typeof item.binary !== 'object') {
                    throw new Error('The binary-property has to be an object!');
                }
            }
        }
        return this.prepareOutputData(items);
    }
}
exports.Function = Function;
//# sourceMappingURL=Function.node.js.map