"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.ghostApiRequestAllItems = exports.ghostApiRequest = void 0;
const jwt = require("jsonwebtoken");
async function ghostApiRequest(method, endpoint, body = {}, query = {}, uri) {
    const source = this.getNodeParameter('source', 0);
    let credentials;
    let version;
    let token;
    if (source === 'contentApi') {
        version = 'v3';
        credentials = this.getCredentials('ghostContentApi');
        query.key = credentials.apiKey;
    }
    else {
        version = 'v2';
        credentials = this.getCredentials('ghostAdminApi');
        const [id, secret] = credentials.apiKey.split(':');
        token = jwt.sign({}, Buffer.from(secret, 'hex'), {
            keyid: id,
            algorithm: 'HS256',
            expiresIn: '5m',
            audience: `/${version}/admin/`,
        });
    }
    const options = {
        method,
        qs: query,
        uri: uri || `${credentials.url}/ghost/api/${version}${endpoint}`,
        body,
        json: true,
    };
    if (token) {
        options.headers = {
            Authorization: `Ghost ${token}`,
        };
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessages;
        if (error.response && error.response.body && error.response.body.errors) {
            if (Array.isArray(error.response.body.errors)) {
                const errors = error.response.body.errors;
                errorMessages = errors.map((e) => e.message);
            }
            throw new Error(`Ghost error response [${error.statusCode}]: ${errorMessages === null || errorMessages === void 0 ? void 0 : errorMessages.join('|')}`);
        }
        throw error;
    }
}
exports.ghostApiRequest = ghostApiRequest;
async function ghostApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.limit = 20;
    let uri;
    do {
        responseData = await ghostApiRequest.call(this, method, endpoint, body, query, uri);
        uri = responseData.meta.pagination.next;
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.meta.pagination.next !== null);
    return returnData;
}
exports.ghostApiRequestAllItems = ghostApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map