"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.simplify = exports.googleApiRequestAllItems = exports.googleApiRequest = void 0;
async function googleApiRequest(method, endpoint, body = {}, qs = {}, uri, option = {}) {
    let options = {
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://analyticsreporting.googleapis.com${endpoint}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.requestOAuth2.call(this, 'googleAnalyticsOAuth2', options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            let errorMessages;
            if (error.response.body.error.errors) {
                errorMessages = error.response.body.error.errors;
                errorMessages = errorMessages.map((errorItem) => errorItem.message);
                errorMessages = errorMessages.join('|');
            }
            else if (error.response.body.error.message) {
                errorMessages = error.response.body.error.message;
            }
            throw new Error(`Google Analytics error response [${error.statusCode}]: ${errorMessages}`);
        }
        throw error;
    }
}
exports.googleApiRequest = googleApiRequest;
async function googleApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}, uri) {
    const returnData = [];
    let responseData;
    body.pageSize = 100;
    do {
        responseData = await googleApiRequest.call(this, method, endpoint, body, query, uri);
        if (body.reportRequests && Array.isArray(body.reportRequests)) {
            body.reportRequests[0].pageToken = responseData['nextPageToken'];
        }
        else {
            body.pageToken = responseData['nextPageToken'];
        }
        returnData.push.apply(returnData, responseData[propertyName]);
    } while ((responseData['nextPageToken'] !== undefined &&
        responseData['nextPageToken'] !== '') ||
        (responseData['reports'] &&
            responseData['reports'][0].nextPageToken &&
            responseData['reports'][0].nextPageToken !== undefined));
    return returnData;
}
exports.googleApiRequestAllItems = googleApiRequestAllItems;
function simplify(responseData) {
    const { columnHeader: { dimensions }, data: { rows } } = responseData[0];
    responseData = [];
    for (const row of rows) {
        const data = {};
        if (dimensions) {
            for (let i = 0; i < dimensions.length; i++) {
                data[dimensions[i]] = row.dimensions[i];
                data['total'] = row.metrics[0].values.join(',');
            }
        }
        else {
            data['total'] = row.metrics[0].values.join(',');
        }
        responseData.push(data);
    }
    return responseData;
}
exports.simplify = simplify;
//# sourceMappingURL=GenericFunctions.js.map