"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.googleApiRequest = void 0;
async function googleApiRequest(method, endpoint, body = {}, qs = {}, uri, option = {}) {
    let options = {
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://language.googleapis.com${endpoint}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.requestOAuth2.call(this, 'googleCloudNaturalLanguageOAuth2Api', options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            let errorMessages;
            if (error.response.body.error.errors) {
                errorMessages = error.response.body.error.errors;
                errorMessages = errorMessages.map((errorItem) => errorItem.message);
                errorMessages = errorMessages.join('|');
            }
            else if (error.response.body.error.message) {
                errorMessages = error.response.body.error.message;
            }
            throw new Error(`Google Cloud Natural Language error response [${error.statusCode}]: ${errorMessages}`);
        }
        throw error;
    }
}
exports.googleApiRequest = googleApiRequest;
//# sourceMappingURL=GenericFunctions.js.map