"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GoogleTasks = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const TaskDescription_1 = require("./TaskDescription");
class GoogleTasks {
    constructor() {
        this.description = {
            displayName: 'Google Tasks',
            name: 'googleTasks',
            icon: 'file:googleTasks.png',
            group: ['input'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Consume Google Tasks API.',
            defaults: {
                name: 'Google Tasks',
                color: '#3E87E4',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'googleTasksOAuth2Api',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    options: [
                        {
                            name: 'Task',
                            value: 'task',
                        },
                    ],
                    default: 'task',
                    description: 'The resource to operate on.',
                },
                ...TaskDescription_1.taskOperations,
                ...TaskDescription_1.taskFields,
            ],
        };
        this.methods = {
            loadOptions: {
                async getTasks() {
                    const returnData = [];
                    const tasks = await GenericFunctions_1.googleApiRequestAllItems.call(this, 'items', 'GET', '/tasks/v1/users/@me/lists');
                    for (const task of tasks) {
                        const taskName = task.title;
                        const taskId = task.id;
                        returnData.push({
                            name: taskName,
                            value: taskId,
                        });
                    }
                    return returnData;
                },
            },
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        const qs = {};
        let responseData;
        const resource = this.getNodeParameter('resource', 0);
        const operation = this.getNodeParameter('operation', 0);
        let body = {};
        for (let i = 0; i < length; i++) {
            if (resource === 'task') {
                if (operation === 'create') {
                    body = {};
                    const taskId = this.getNodeParameter('task', i);
                    body.title = this.getNodeParameter('title', i);
                    const additionalFields = this.getNodeParameter('additionalFields', i);
                    if (additionalFields.parent) {
                        qs.parent = additionalFields.parent;
                    }
                    if (additionalFields.previous) {
                        qs.previous = additionalFields.previous;
                    }
                    if (additionalFields.status) {
                        body.status = additionalFields.status;
                    }
                    if (additionalFields.notes) {
                        body.notes = additionalFields.notes;
                    }
                    if (additionalFields.dueDate) {
                        body.dueDate = additionalFields.dueDate;
                    }
                    if (additionalFields.completed) {
                        body.completed = additionalFields.completed;
                    }
                    if (additionalFields.deleted) {
                        body.deleted = additionalFields.deleted;
                    }
                    responseData = await GenericFunctions_1.googleApiRequest.call(this, 'POST', `/tasks/v1/lists/${taskId}/tasks`, body, qs);
                }
                if (operation === 'delete') {
                    const taskListId = this.getNodeParameter('task', i);
                    const taskId = this.getNodeParameter('taskId', i);
                    responseData = await GenericFunctions_1.googleApiRequest.call(this, 'DELETE', `/tasks/v1/lists/${taskListId}/tasks/${taskId}`, {});
                    responseData = { success: true };
                }
                if (operation === 'get') {
                    const taskListId = this.getNodeParameter('task', i);
                    const taskId = this.getNodeParameter('taskId', i);
                    responseData = await GenericFunctions_1.googleApiRequest.call(this, 'GET', `/tasks/v1/lists/${taskListId}/tasks/${taskId}`, {}, qs);
                }
                if (operation === 'getAll') {
                    const returnAll = this.getNodeParameter('returnAll', i);
                    const taskListId = this.getNodeParameter('task', i);
                    const options = this.getNodeParameter('additionalFields', i);
                    if (options.completedMax) {
                        qs.completedMax = options.completedMax;
                    }
                    if (options.completedMin) {
                        qs.completedMin = options.completedMin;
                    }
                    if (options.dueMin) {
                        qs.dueMin = options.dueMin;
                    }
                    if (options.dueMax) {
                        qs.dueMax = options.dueMax;
                    }
                    if (options.showCompleted) {
                        qs.showCompleted = options.showCompleted;
                    }
                    if (options.showDeleted) {
                        qs.showDeleted = options.showDeleted;
                    }
                    if (options.showHidden) {
                        qs.showHidden = options.showHidden;
                    }
                    if (options.updatedMin) {
                        qs.updatedMin = options.updatedMin;
                    }
                    if (returnAll) {
                        responseData = await GenericFunctions_1.googleApiRequestAllItems.call(this, 'items', 'GET', `/tasks/v1/lists/${taskListId}/tasks`, {}, qs);
                    }
                    else {
                        qs.maxResults = this.getNodeParameter('limit', i);
                        responseData = await GenericFunctions_1.googleApiRequest.call(this, 'GET', `/tasks/v1/lists/${taskListId}/tasks`, {}, qs);
                        responseData = responseData.items;
                    }
                }
                if (operation === 'update') {
                    body = {};
                    const taskListId = this.getNodeParameter('task', i);
                    const taskId = this.getNodeParameter('taskId', i);
                    const updateFields = this.getNodeParameter('updateFields', i);
                    if (updateFields.previous) {
                        qs.previous = updateFields.previous;
                    }
                    if (updateFields.status) {
                        body.status = updateFields.status;
                    }
                    if (updateFields.notes) {
                        body.notes = updateFields.notes;
                    }
                    if (updateFields.title) {
                        body.title = updateFields.title;
                    }
                    if (updateFields.dueDate) {
                        body.dueDate = updateFields.dueDate;
                    }
                    if (updateFields.completed) {
                        body.completed = updateFields.completed;
                    }
                    if (updateFields.deleted) {
                        body.deleted = updateFields.deleted;
                    }
                    responseData = await GenericFunctions_1.googleApiRequest.call(this, 'PATCH', `/tasks/v1/lists/${taskListId}/tasks/${taskId}`, body, qs);
                }
            }
            if (Array.isArray(responseData)) {
                returnData.push.apply(returnData, responseData);
            }
            else if (responseData !== undefined) {
                returnData.push(responseData);
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.GoogleTasks = GoogleTasks;
//# sourceMappingURL=GoogleTasks.node.js.map