"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.gotifyApiRequestAllItems = exports.gotifyApiRequest = void 0;
async function gotifyApiRequest(method, path, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('gotifyApi');
    const options = {
        method,
        headers: {
            'X-Gotify-Key': (method === 'POST') ? credentials.appApiToken : credentials.clientApiToken,
            accept: 'application/json',
        },
        body,
        qs,
        uri: uri || `${credentials.url}${path}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.request.call(this, options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.errorDescription) {
            const message = error.response.body.errorDescription;
            throw new Error(`Gotify error response [${error.statusCode}]: ${message}`);
        }
        throw error;
    }
}
exports.gotifyApiRequest = gotifyApiRequest;
async function gotifyApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query.limit = 100;
    do {
        responseData = await gotifyApiRequest.call(this, method, endpoint, body, query, uri);
        if (responseData.paging.next) {
            uri = responseData.paging.next;
        }
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.paging.next);
    return returnData;
}
exports.gotifyApiRequestAllItems = gotifyApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map