"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hunterApiRequestAllItems = exports.hunterApiRequest = void 0;
async function hunterApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('hunterApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    qs = Object.assign({ api_key: credentials.apiKey }, qs);
    let options = {
        method,
        qs,
        body,
        uri: uri || `https://api.hunter.io/v2${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (err) {
        throw new Error(err);
    }
}
exports.hunterApiRequest = hunterApiRequest;
async function hunterApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.offset = 0;
    query.limit = 100;
    do {
        responseData = await hunterApiRequest.call(this, method, resource, body, query);
        returnData.push(responseData[propertyName]);
        query.offset += query.limit;
    } while (responseData.meta !== undefined &&
        responseData.meta.results !== undefined &&
        responseData.meta.offset <= responseData.meta.results);
    return returnData;
}
exports.hunterApiRequestAllItems = hunterApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map