"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.intercomApiRequestAllItems = exports.intercomApiRequest = void 0;
async function intercomApiRequest(endpoint, method, body = {}, query, uri) {
    const credentials = this.getCredentials('intercomApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const headerWithAuthentication = Object.assign({}, { Authorization: `Bearer ${credentials.apiKey}`, Accept: 'application/json' });
    const options = {
        headers: headerWithAuthentication,
        method,
        qs: query,
        uri: uri || `https://api.intercom.io${endpoint}`,
        body,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        const errorMessage = error.response.body.message || error.response.body.Message;
        if (errorMessage !== undefined) {
            throw errorMessage;
        }
        throw error.response.body;
    }
}
exports.intercomApiRequest = intercomApiRequest;
async function intercomApiRequestAllItems(propertyName, endpoint, method, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.per_page = 60;
    let uri;
    do {
        responseData = await intercomApiRequest.call(this, endpoint, method, body, query, uri);
        uri = responseData.pages.next;
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.pages !== undefined &&
        responseData.pages.next !== undefined &&
        responseData.pages.next !== null);
    return returnData;
}
exports.intercomApiRequestAllItems = intercomApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = '';
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map