"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.contactNoteFields = exports.contactNoteOperations = void 0;
exports.contactNoteOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        displayOptions: {
            show: {
                resource: [
                    'contactNote',
                ],
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: 'Create a note',
            },
            {
                name: 'Delete',
                value: 'delete',
                description: 'Delete a note',
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Get a notes',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'Retrieve all notes',
            },
            {
                name: 'Update',
                value: 'update',
                description: 'Update a note',
            },
        ],
        default: 'create',
        description: 'The operation to perform.',
    },
];
exports.contactNoteFields = [
    {
        displayName: 'User ID',
        name: 'userId',
        type: 'options',
        typeOptions: {
            loadOptionsMethod: 'getUsers',
        },
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        default: '',
        description: 'The infusionsoft user to create the note on behalf of',
    },
    {
        displayName: 'Contact ID',
        name: 'contactId',
        type: 'string',
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        default: '',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        options: [
            {
                displayName: 'Body',
                name: 'body',
                type: 'string',
                typeOptions: {
                    alwaysOpenEditWindow: true,
                },
                default: '',
            },
            {
                displayName: 'Title',
                name: 'title',
                type: 'string',
                default: '',
            },
            {
                displayName: 'Type',
                name: 'type',
                type: 'options',
                options: [
                    {
                        name: 'Appointment',
                        value: 'appointment',
                    },
                    {
                        name: 'Call',
                        value: 'call',
                    },
                    {
                        name: 'Email',
                        value: 'email',
                    },
                    {
                        name: 'Fax',
                        value: 'fax',
                    },
                    {
                        name: 'Letter',
                        value: 'letter',
                    },
                    {
                        name: 'Other',
                        value: 'other',
                    },
                ],
                default: '',
            },
        ],
    },
    {
        displayName: 'Note ID',
        name: 'noteId',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                operation: [
                    'delete',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        default: '',
    },
    {
        displayName: 'Note ID',
        name: 'noteId',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                operation: [
                    'get',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        default: '',
    },
    {
        displayName: 'Return All',
        name: 'returnAll',
        type: 'boolean',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        default: false,
        description: 'If all results should be returned or only up to a given limit.',
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'contactNote',
                ],
                returnAll: [
                    false,
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 200,
        },
        default: 100,
        description: 'How many results to return.',
    },
    {
        displayName: 'Filters',
        name: 'filters',
        type: 'collection',
        placeholder: 'Add Filter',
        default: {},
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        options: [
            {
                displayName: 'Contact ID',
                name: 'contactId',
                type: 'number',
                typeOptions: {
                    minValue: 0,
                },
                default: 0,
            },
            {
                displayName: 'User ID',
                name: 'userId',
                type: 'options',
                typeOptions: {
                    loadOptionsMethod: 'getUsers',
                },
                default: '',
            },
        ],
    },
    {
        displayName: 'Note ID',
        name: 'noteId',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                operation: [
                    'update',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        default: '',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                operation: [
                    'update',
                ],
                resource: [
                    'contactNote',
                ],
            },
        },
        options: [
            {
                displayName: 'Body',
                name: 'body',
                type: 'string',
                typeOptions: {
                    alwaysOpenEditWindow: true,
                },
                default: '',
            },
            {
                displayName: 'Contact ID',
                name: 'contactId',
                type: 'number',
                typeOptions: {
                    minValue: 0,
                },
                default: 0,
            },
            {
                displayName: 'Title',
                name: 'title',
                type: 'string',
                default: '',
            },
            {
                displayName: 'Type',
                name: 'type',
                type: 'options',
                options: [
                    {
                        name: 'Appointment',
                        value: 'appointment',
                    },
                    {
                        name: 'Call',
                        value: 'call',
                    },
                    {
                        name: 'Email',
                        value: 'email',
                    },
                    {
                        name: 'Fax',
                        value: 'fax',
                    },
                    {
                        name: 'Letter',
                        value: 'letter',
                    },
                    {
                        name: 'Other',
                        value: 'other',
                    },
                ],
                default: '',
            },
            {
                displayName: 'User ID',
                name: 'userId',
                type: 'options',
                typeOptions: {
                    loadOptionsMethod: 'getUsers',
                },
                default: '',
                description: 'The infusionsoft user to create the note on behalf of',
            },
        ],
    },
];
//# sourceMappingURL=ContactNoteDescription.js.map