"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lingvaNexApiRequest = void 0;
async function lingvaNexApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    try {
        const credentials = this.getCredentials('lingvaNexApi');
        if (credentials === undefined) {
            throw new Error('No credentials got returned!');
        }
        let options = {
            headers: {
                Authorization: `Bearer ${credentials.apiKey}`,
            },
            method,
            qs,
            body,
            uri: uri || `https://api-b2b.backenster.com/b1/api/v3${resource}`,
            json: true,
        };
        options = Object.assign({}, options, option);
        const response = await this.helpers.request(options);
        if (response.err !== null) {
            throw new Error(`LingvaNex error response [400]: ${response.err}`);
        }
        return response;
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            const errorBody = error.response.body;
            throw new Error(`LingvaNex error response [${error.statusCode}]: ${errorBody.message}`);
        }
        throw error;
    }
}
exports.lingvaNexApiRequest = lingvaNexApiRequest;
//# sourceMappingURL=GenericFunctions.js.map