"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mailerliteApiRequestAllItems = exports.mailerliteApiRequest = void 0;
async function mailerliteApiRequest(method, path, body = {}, qs = {}, option = {}) {
    const credentials = this.getCredentials('mailerLiteApi');
    const options = {
        headers: {
            'X-MailerLite-ApiKey': credentials.apiKey,
        },
        method,
        body,
        qs,
        uri: `https://api.mailerlite.com/api/v2${path}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.request.call(this, options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            const message = error.response.body.error.message;
            throw new Error(`Mailer Lite error response [${error.statusCode}]: ${message}`);
        }
        throw error;
    }
}
exports.mailerliteApiRequest = mailerliteApiRequest;
async function mailerliteApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.limit = 1000;
    query.offset = 0;
    do {
        responseData = await mailerliteApiRequest.call(this, method, endpoint, body, query);
        returnData.push.apply(returnData, responseData);
        query.offset = query.offset + query.limit;
    } while (responseData.length !== 0);
    return returnData;
}
exports.mailerliteApiRequestAllItems = mailerliteApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map