"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.getTags = exports.getGoogleAnalyticsDomainsArray = exports.getToEmailArray = exports.mandrillApiRequest = void 0;
const _ = require("lodash");
async function mandrillApiRequest(resource, method, action, body = {}, headers) {
    const credentials = this.getCredentials('mandrillApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const data = Object.assign({}, body, { key: credentials.apiKey });
    const endpoint = 'mandrillapp.com/api/1.0';
    const options = {
        headers,
        method,
        uri: `https://${endpoint}${resource}${action}.json`,
        body: data,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        const errorMessage = error.response.body.message || error.response.body.Message;
        if (error.name === 'Invalid_Key') {
            throw new Error('The provided API key is not a valid Mandrill API key');
        }
        else if (error.name === 'ValidationError') {
            throw new Error('The parameters passed to the API call are invalid or not provided when required');
        }
        else if (error.name === 'GeneralError') {
            throw new Error('An unexpected error occurred processing the request. Mandrill developers will be notified.');
        }
        if (errorMessage !== undefined) {
            throw errorMessage;
        }
        throw error.response.body;
    }
}
exports.mandrillApiRequest = mandrillApiRequest;
function getToEmailArray(toEmail) {
    let toEmailArray;
    if (toEmail.split(',').length > 0) {
        const array = toEmail.split(',');
        toEmailArray = _.map(array, (email) => {
            return {
                email,
                type: 'to',
            };
        });
    }
    else {
        toEmailArray = [{
                email: toEmail,
                type: 'to',
            }];
    }
    return toEmailArray;
}
exports.getToEmailArray = getToEmailArray;
function getGoogleAnalyticsDomainsArray(s) {
    let array = [];
    if (s.split(',').length > 0) {
        array = s.split(',');
    }
    else {
        array = [s];
    }
    return array;
}
exports.getGoogleAnalyticsDomainsArray = getGoogleAnalyticsDomainsArray;
function getTags(s) {
    let array = [];
    if (s.split(',').length > 0) {
        array = s.split(',');
    }
    else {
        array = [s];
    }
    return array;
}
exports.getTags = getTags;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = [];
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map