"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.messageBirdApiRequest = void 0;
async function messageBirdApiRequest(method, resource, body, query = {}) {
    const credentials = this.getCredentials('messageBirdApi');
    if (credentials === undefined) {
        throw new Error('No credentials returned!');
    }
    const options = {
        headers: {
            Accept: 'application/json',
            Authorization: `AccessKey ${credentials.accessKey}`,
        },
        method,
        qs: query,
        body,
        uri: `https://rest.messagebird.com${resource}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Message Bird credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.errors) {
            const errorMessage = error.response.body.errors.map((e) => e.description);
            throw new Error(`MessageBird Error response [${error.statusCode}]: ${errorMessage.join('|')}`);
        }
        throw error;
    }
}
exports.messageBirdApiRequest = messageBirdApiRequest;
//# sourceMappingURL=GenericFunctions.js.map