"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.microsoftApiRequestAllItemsSkip = exports.microsoftApiRequestAllItems = exports.microsoftApiRequest = void 0;
async function microsoftApiRequest(method, resource, body = {}, qs = {}, uri, headers = {}) {
    const options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://graph.microsoft.com/v1.0/me${resource}`,
        json: true,
    };
    try {
        if (Object.keys(headers).length !== 0) {
            options.headers = Object.assign({}, options.headers, headers);
        }
        return await this.helpers.requestOAuth2.call(this, 'microsoftExcelOAuth2Api', options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error && error.response.body.error.message) {
            throw new Error(`Microsoft error response [${error.statusCode}]: ${error.response.body.error.message}`);
        }
        throw error;
    }
}
exports.microsoftApiRequest = microsoftApiRequest;
async function microsoftApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query['$top'] = 100;
    do {
        responseData = await microsoftApiRequest.call(this, method, endpoint, body, query, uri);
        uri = responseData['@odata.nextLink'];
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData['@odata.nextLink'] !== undefined);
    return returnData;
}
exports.microsoftApiRequestAllItems = microsoftApiRequestAllItems;
async function microsoftApiRequestAllItemsSkip(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query['$top'] = 100;
    query['$skip'] = 0;
    do {
        responseData = await microsoftApiRequest.call(this, method, endpoint, body, query);
        query['$skip'] += query['$top'];
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData['value'].length !== 0);
    return returnData;
}
exports.microsoftApiRequestAllItemsSkip = microsoftApiRequestAllItemsSkip;
//# sourceMappingURL=GenericFunctions.js.map