"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanData = exports.mindeeApiRequest = void 0;
async function mindeeApiRequest(method, path, body = {}, qs = {}, option = {}) {
    const resource = this.getNodeParameter('resource', 0);
    let credentials;
    if (resource === 'receipt') {
        credentials = this.getCredentials('mindeeReceiptApi');
    }
    else {
        credentials = this.getCredentials('mindeeInvoiceApi');
    }
    const options = {
        headers: {
            'X-Inferuser-Token': credentials.apiKey,
        },
        method,
        body,
        qs,
        uri: `https://api.mindee.net/products${path}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        if (Object.keys(qs).length === 0) {
            delete options.qs;
        }
        if (Object.keys(option).length !== 0) {
            Object.assign(options, option);
        }
        return await this.helpers.request.call(this, options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            let errors = error.response.body.error.errors;
            errors = errors.map((e) => e.message);
            throw new Error(`Mindee error response [${error.statusCode}]: ${errors.join('|')}`);
        }
        throw error;
    }
}
exports.mindeeApiRequest = mindeeApiRequest;
function cleanData(predictions) {
    const newData = {};
    for (const key of Object.keys(predictions[0])) {
        const data = predictions[0][key];
        if (key === 'taxes' && data.length) {
            newData[key] = {
                amount: data[0].amount,
                rate: data[0].rate,
            };
        }
        else if (key === 'locale') {
            newData['currency'] = data.currency;
            newData['locale'] = data.value;
        }
        else {
            newData[key] = data.value || data.name || data.raw || data.degrees || data.amount || data.iban;
        }
    }
    return newData;
}
exports.cleanData = cleanData;
//# sourceMappingURL=GenericFunctions.js.map