"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mondayComApiRequestAllItems = exports.mondayComApiRequest = void 0;
const lodash_1 = require("lodash");
async function mondayComApiRequest(body = {}, option = {}) {
    const credentials = this.getCredentials('mondayComApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const endpoint = 'https://api.monday.com/v2/';
    let options = {
        headers: {
            'Content-Type': 'application/json',
            'Authorization': credentials.apiToken,
        },
        method: 'POST',
        body,
        uri: endpoint,
        json: true,
    };
    options = Object.assign({}, options, option);
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response) {
            const errorMessage = error.response.body.error_message;
            throw new Error(`Monday error response [${error.statusCode}]: ${errorMessage}`);
        }
        throw error;
    }
}
exports.mondayComApiRequest = mondayComApiRequest;
async function mondayComApiRequestAllItems(propertyName, body = {}) {
    const returnData = [];
    let responseData;
    body.variables.limit = 50;
    body.variables.page = 1;
    do {
        responseData = await mondayComApiRequest.call(this, body);
        returnData.push.apply(returnData, lodash_1.get(responseData, propertyName));
        body.variables.page++;
    } while (lodash_1.get(responseData, propertyName).length > 0);
    return returnData;
}
exports.mondayComApiRequestAllItems = mondayComApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map