"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongoDb = void 0;
const mongo_node_options_1 = require("./mongo.node.options");
const mongodb_1 = require("mongodb");
const mongo_node_utils_1 = require("./mongo.node.utils");
class MongoDb {
    constructor() {
        this.description = mongo_node_options_1.nodeDescription;
    }
    async execute() {
        const { database, connectionString } = mongo_node_utils_1.validateAndResolveMongoCredentials(this.getCredentials('mongoDb'));
        const client = await mongodb_1.MongoClient.connect(connectionString, {
            useNewUrlParser: true,
            useUnifiedTopology: true,
        });
        const mdb = client.db(database);
        let returnItems = [];
        const items = this.getInputData();
        const operation = this.getNodeParameter('operation', 0);
        if (operation === 'delete') {
            const { deletedCount } = await mdb
                .collection(this.getNodeParameter('collection', 0))
                .deleteMany(JSON.parse(this.getNodeParameter('query', 0)));
            returnItems = this.helpers.returnJsonArray([{ deletedCount }]);
        }
        else if (operation === 'find') {
            const queryResult = await mdb
                .collection(this.getNodeParameter('collection', 0))
                .find(JSON.parse(this.getNodeParameter('query', 0)))
                .toArray();
            returnItems = this.helpers.returnJsonArray(queryResult);
        }
        else if (operation === 'insert') {
            const fields = this.getNodeParameter('fields', 0)
                .split(',')
                .map(f => f.trim())
                .filter(f => !!f);
            const insertItems = mongo_node_utils_1.getItemCopy(items, fields);
            const { insertedIds } = await mdb
                .collection(this.getNodeParameter('collection', 0))
                .insertMany(insertItems);
            for (const i of Object.keys(insertedIds)) {
                returnItems.push({
                    json: Object.assign(Object.assign({}, insertItems[parseInt(i, 10)]), { id: insertedIds[parseInt(i, 10)] }),
                });
            }
        }
        else if (operation === 'update') {
            const fields = this.getNodeParameter('fields', 0)
                .split(',')
                .map(f => f.trim())
                .filter(f => !!f);
            let updateKey = this.getNodeParameter('updateKey', 0);
            updateKey = updateKey.trim();
            if (!fields.includes(updateKey)) {
                fields.push(updateKey);
            }
            const updateItems = mongo_node_utils_1.getItemCopy(items, fields);
            for (const item of updateItems) {
                if (item[updateKey] === undefined) {
                    continue;
                }
                const filter = {};
                filter[updateKey] = item[updateKey];
                await mdb
                    .collection(this.getNodeParameter('collection', 0))
                    .updateOne(filter, { $set: item });
            }
            returnItems = this.helpers.returnJsonArray(updateItems);
        }
        else {
            throw new Error(`The operation "${operation}" is not supported!`);
        }
        return this.prepareOutputData(returnItems);
    }
}
exports.MongoDb = MongoDb;
//# sourceMappingURL=MongoDb.node.js.map