"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getItemCopy = exports.validateAndResolveMongoCredentials = void 0;
function buildParameterizedConnString(credentials) {
    if (credentials.port) {
        return `mongodb://${credentials.user}:${credentials.password}@${credentials.host}:${credentials.port}`;
    }
    else {
        return `mongodb+srv://${credentials.user}:${credentials.password}@${credentials.host}`;
    }
}
function buildMongoConnectionParams(credentials) {
    const sanitizedDbName = credentials.database && credentials.database.trim().length > 0
        ? credentials.database.trim()
        : '';
    if (credentials.configurationType === 'connectionString') {
        if (credentials.connectionString &&
            credentials.connectionString.trim().length > 0) {
            return {
                connectionString: credentials.connectionString.trim(),
                database: sanitizedDbName,
            };
        }
        else {
            throw new Error('Cannot override credentials: valid MongoDB connection string not provided ');
        }
    }
    else {
        return {
            connectionString: buildParameterizedConnString(credentials),
            database: sanitizedDbName,
        };
    }
}
function validateAndResolveMongoCredentials(credentials) {
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    else {
        return buildMongoConnectionParams(credentials);
    }
}
exports.validateAndResolveMongoCredentials = validateAndResolveMongoCredentials;
function getItemCopy(items, properties) {
    let newItem;
    return items.map(item => {
        newItem = {};
        for (const property of properties) {
            if (item.json[property] === undefined) {
                newItem[property] = null;
            }
            else {
                newItem[property] = JSON.parse(JSON.stringify(item.json[property]));
            }
        }
        return newItem;
    });
}
exports.getItemCopy = getItemCopy;
//# sourceMappingURL=mongo.node.utils.js.map