"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.nasaApiRequestAllItems = exports.nasaApiRequest = void 0;
async function nasaApiRequest(method, endpoint, qs, option = {}, uri) {
    const credentials = this.getCredentials('nasaApi');
    qs.api_key = credentials['api_key'];
    const options = {
        method,
        qs,
        uri: uri || `https://api.nasa.gov${endpoint}`,
        json: true,
    };
    if (Object.keys(option)) {
        Object.assign(options, option);
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The NASA credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.msg) {
            throw new Error(`NASA error response [${error.statusCode}]: ${error.response.body.msg}`);
        }
        throw error;
    }
}
exports.nasaApiRequest = nasaApiRequest;
async function nasaApiRequestAllItems(propertyName, method, resource, query = {}) {
    const returnData = [];
    let responseData;
    query.size = 20;
    let uri = undefined;
    do {
        responseData = await nasaApiRequest.call(this, method, resource, query, {}, uri);
        uri = responseData.links.next;
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.links.next !== undefined);
    return returnData;
}
exports.nasaApiRequestAllItems = nasaApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map