"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUser = exports.philipsHueApiRequest = void 0;
async function philipsHueApiRequest(method, resource, body = {}, qs = {}, uri, headers = {}) {
    const options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://api.meethue.com${resource}`,
        json: true,
    };
    try {
        if (Object.keys(headers).length !== 0) {
            options.headers = Object.assign({}, options.headers, headers);
        }
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        if (Object.keys(qs).length === 0) {
            delete options.qs;
        }
        return await this.helpers.requestOAuth2.call(this, 'philipsHueOAuth2Api', options, { tokenType: 'Bearer' });
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            const errorMessage = error.response.body.error.description;
            throw new Error(`Philip Hue error response [${error.statusCode}]: ${errorMessage}`);
        }
        throw error;
    }
}
exports.philipsHueApiRequest = philipsHueApiRequest;
async function getUser() {
    const { whitelist } = await philipsHueApiRequest.call(this, 'GET', '/bridge/0/config', {}, {});
    for (const user of Object.keys(whitelist)) {
        if (whitelist[user].name === 'n8n') {
            return user;
        }
    }
    await philipsHueApiRequest.call(this, 'PUT', '/bridge/0/config', { linkbutton: true });
    const { success } = await philipsHueApiRequest.call(this, 'POST', '/bridge', { devicetype: 'n8n' });
    return success.username;
}
exports.getUser = getUser;
//# sourceMappingURL=GenericFunctions.js.map