"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReadBinaryFile = void 0;
const fs_1 = require("fs");
const util_1 = require("util");
const fsReadFileAsync = util_1.promisify(fs_1.readFile);
class ReadBinaryFile {
    constructor() {
        this.description = {
            displayName: 'Read Binary File',
            name: 'readBinaryFile',
            icon: 'fa:file-import',
            group: ['input'],
            version: 1,
            description: 'Reads a binary file from disk',
            defaults: {
                name: 'Read Binary File',
                color: '#449922',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'File Path',
                    name: 'filePath',
                    type: 'string',
                    default: '',
                    required: true,
                    placeholder: '/data/example.jpg',
                    description: 'Path of the file to read.',
                },
                {
                    displayName: 'Property Name',
                    name: 'dataPropertyName',
                    type: 'string',
                    default: 'data',
                    required: true,
                    description: 'Name of the binary property to which to<br />write the data of the read file.',
                },
            ],
        };
    }
    async executeSingle() {
        const item = this.getInputData();
        const dataPropertyName = this.getNodeParameter('dataPropertyName');
        const filePath = this.getNodeParameter('filePath');
        let data;
        try {
            data = await fsReadFileAsync(filePath);
        }
        catch (error) {
            if (error.code === 'ENOENT') {
                throw new Error(`The file "${filePath}" could not be found.`);
            }
            throw error;
        }
        const newItem = {
            json: item.json,
            binary: {},
        };
        if (item.binary !== undefined) {
            Object.assign(newItem.binary, item.binary);
        }
        newItem.binary[dataPropertyName] = await this.helpers.prepareBinaryData(data, filePath);
        return newItem;
    }
}
exports.ReadBinaryFile = ReadBinaryFile;
//# sourceMappingURL=ReadBinaryFile.node.js.map