"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.rocketchatApiRequest = void 0;
async function rocketchatApiRequest(resource, method, operation, body = {}, headers) {
    const credentials = this.getCredentials('rocketchatApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const headerWithAuthentication = Object.assign({}, headers, { 'X-Auth-Token': credentials.authKey, 'X-User-Id': credentials.userId });
    const options = {
        headers: headerWithAuthentication,
        method,
        body,
        uri: `${credentials.domain}/api/v1${resource}.${operation}`,
        json: true,
    };
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.response.body.error) {
            errorMessage = error.response.body.error;
        }
        throw new Error(`Rocket.chat error response [${error.statusCode}]: ${errorMessage}`);
    }
}
exports.rocketchatApiRequest = rocketchatApiRequest;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = [];
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map