"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RundeckApi = void 0;
class RundeckApi {
    constructor(executeFunctions) {
        const credentials = executeFunctions.getCredentials('rundeckApi');
        if (credentials === undefined) {
            throw new Error('No credentials got returned!');
        }
        this.credentials = credentials;
        this.executeFunctions = executeFunctions;
    }
    async request(method, endpoint, body, query) {
        const options = {
            headers: {
                'user-agent': 'n8n',
                'X-Rundeck-Auth-Token': this.credentials.token,
            },
            rejectUnauthorized: false,
            method,
            qs: query,
            uri: this.credentials.url + endpoint,
            body,
            json: true,
        };
        try {
            return await this.executeFunctions.helpers.request(options);
        }
        catch (error) {
            let errorMessage = error.message;
            if (error.response && error.response.body && error.response.body.message) {
                errorMessage = error.response.body.message.replace('\n', '');
            }
            throw Error(`Rundeck Error [${error.statusCode}]: ${errorMessage}`);
        }
    }
    executeJob(jobId, args) {
        let params = '';
        if (args) {
            for (const arg of args) {
                params += '-' + arg.name + ' ' + arg.value + ' ';
            }
        }
        const body = {
            argString: params,
        };
        return this.request('POST', `/api/14/job/${jobId}/run`, body, {});
    }
    getJobMetadata(jobId) {
        return this.request('GET', `/api/18/job/${jobId}/info`, {}, {});
    }
}
exports.RundeckApi = RundeckApi;
//# sourceMappingURL=RundeckApi.js.map