"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.simplifySalesmateData = exports.validateJSON = exports.salesmateApiRequestAllItems = exports.salesmateApiRequest = void 0;
async function salesmateApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('salesmateApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const options = {
        headers: {
            'sessionToken': credentials.sessionToken,
            'x-linkname': credentials.url,
            'Content-Type': 'application/json',
        },
        method,
        qs,
        body,
        uri: uri || `https://apis.salesmate.io${resource}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new Error('Salesmate Error: ' + error);
    }
}
exports.salesmateApiRequest = salesmateApiRequest;
async function salesmateApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.pageNo = 1;
    query.rows = 25;
    do {
        responseData = await salesmateApiRequest.call(this, method, resource, body, query);
        returnData.push.apply(returnData, responseData[propertyName].data);
        query.pageNo++;
    } while (responseData[propertyName].totalPages !== undefined &&
        query.pageNo <= responseData[propertyName].totalPages);
    return returnData;
}
exports.salesmateApiRequestAllItems = salesmateApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
function simplifySalesmateData(data) {
    const returnData = {};
    for (const item of data) {
        returnData[item.fieldName] = item.value;
    }
    return returnData;
}
exports.simplifySalesmateData = simplifySalesmateData;
//# sourceMappingURL=GenericFunctions.js.map