"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.simplify = exports.scorecardApiRequest = void 0;
async function scorecardApiRequest(method, resource, body = {}, query = {}, uri, option = {}) {
    const credentials = this.getCredentials('securityScorecardApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const headerWithAuthentication = { Authorization: `Token ${credentials.apiKey}` };
    let options = {
        headers: headerWithAuthentication,
        method,
        qs: query,
        uri: uri || `https://api.securityscorecard.io/${resource}`,
        body,
        json: true,
    };
    if (Object.keys(option).length !== 0) {
        options = Object.assign({}, options, option);
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    if (Object.keys(query).length === 0) {
        delete options.qs;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.error) {
            const errorMessage = `SecurityScorecard error response [${error.statusCode}]: ${error.error.error ? error.error.error.message : error.error}`;
            throw new Error(errorMessage);
        }
        else
            throw error;
    }
}
exports.scorecardApiRequest = scorecardApiRequest;
function simplify(data) {
    const results = [];
    for (const record of data) {
        const newRecord = { date: record.date };
        for (const factor of record.factors) {
            newRecord[factor.name] = factor.score;
        }
        results.push(newRecord);
    }
    return results;
}
exports.simplify = simplify;
//# sourceMappingURL=GenericFunctions.js.map