"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendGridApiRequestAllItems = exports.sendGridApiRequest = void 0;
async function sendGridApiRequest(endpoint, method, body = {}, qs = {}, uri) {
    const credentials = this.getCredentials('sendGridApi');
    const host = 'api.sendgrid.com/v3';
    const options = {
        headers: {
            Authorization: `Bearer ${credentials.apiKey}`,
        },
        method,
        qs,
        body,
        uri: uri || `https://${host}${endpoint}`,
        json: true,
    };
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.errors) {
            let errors = error.response.body.errors;
            errors = errors.map((e) => e.message);
            throw new Error(`SendGrid error response [${error.statusCode}]: ${errors.join('|')}`);
        }
        throw error;
    }
}
exports.sendGridApiRequest = sendGridApiRequest;
async function sendGridApiRequestAllItems(endpoint, method, propertyName, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    do {
        responseData = await sendGridApiRequest.call(this, endpoint, method, body, query, uri);
        uri = responseData._metadata.next;
        returnData.push.apply(returnData, responseData[propertyName]);
        if (query.limit && returnData.length >= query.limit) {
            return returnData;
        }
    } while (responseData._metadata.next !== undefined);
    return returnData;
}
exports.sendGridApiRequestAllItems = sendGridApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map