"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.spotifyApiRequestAllItems = exports.spotifyApiRequest = void 0;
async function spotifyApiRequest(method, endpoint, body, query, uri) {
    const options = {
        method,
        headers: {
            'User-Agent': 'n8n',
            'Content-Type': 'text/plain',
            'Accept': ' application/json',
        },
        body,
        qs: query,
        uri: uri || `https://api.spotify.com/v1${endpoint}`,
        json: true,
    };
    try {
        const credentials = this.getCredentials('spotifyOAuth2Api');
        if (credentials === undefined) {
            throw new Error('No credentials got returned!');
        }
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.requestOAuth2.call(this, 'spotifyOAuth2Api', options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Spotify credentials are not valid!');
        }
        if (error.error && error.error.error && error.error.error.message) {
            throw new Error(`Spotify error response [${error.error.error.status}]: ${error.error.error.message}`);
        }
        throw error;
    }
}
exports.spotifyApiRequest = spotifyApiRequest;
async function spotifyApiRequestAllItems(propertyName, method, endpoint, body, query) {
    const returnData = [];
    let responseData;
    let uri;
    do {
        responseData = await spotifyApiRequest.call(this, method, endpoint, body, query, uri);
        returnData.push.apply(returnData, responseData[propertyName]);
        uri = responseData.next;
    } while (responseData['next'] !== null);
    return returnData;
}
exports.spotifyApiRequestAllItems = spotifyApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map