"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getImageBySize = exports.apiRequest = exports.addAdditionalFields = void 0;
function addAdditionalFields(body, index) {
    const additionalFields = this.getNodeParameter('additionalFields', index);
    Object.assign(body, additionalFields);
    const operation = this.getNodeParameter('operation', index);
    let replyMarkupOption = '';
    if (operation !== 'sendMediaGroup') {
        replyMarkupOption = this.getNodeParameter('replyMarkup', index);
        if (replyMarkupOption === 'none') {
            return;
        }
    }
    body.reply_markup = {};
    if (['inlineKeyboard', 'replyKeyboard'].includes(replyMarkupOption)) {
        let setParameterName = 'inline_keyboard';
        if (replyMarkupOption === 'replyKeyboard') {
            setParameterName = 'keyboard';
        }
        const keyboardData = this.getNodeParameter(replyMarkupOption, index);
        body.reply_markup[setParameterName] = [];
        let sendButtonData;
        if (keyboardData.rows !== undefined) {
            for (const row of keyboardData.rows) {
                const sendRows = [];
                if (row.row === undefined || row.row.buttons === undefined) {
                    continue;
                }
                for (const button of row.row.buttons) {
                    sendButtonData = {};
                    sendButtonData.text = button.text;
                    if (button.additionalFields) {
                        Object.assign(sendButtonData, button.additionalFields);
                    }
                    sendRows.push(sendButtonData);
                }
                body.reply_markup[setParameterName].push(sendRows);
            }
        }
    }
    else if (replyMarkupOption === 'forceReply') {
        const forceReply = this.getNodeParameter('forceReply', index);
        body.reply_markup = forceReply;
    }
    else if (replyMarkupOption === 'replyKeyboardRemove') {
        const forceReply = this.getNodeParameter('replyKeyboardRemove', index);
        body.reply_markup = forceReply;
    }
    if (replyMarkupOption === 'replyKeyboard') {
        const replyKeyboardOptions = this.getNodeParameter('replyKeyboardOptions', index);
        Object.assign(body.reply_markup, replyKeyboardOptions);
    }
}
exports.addAdditionalFields = addAdditionalFields;
async function apiRequest(method, endpoint, body, query, option = {}) {
    const credentials = this.getCredentials('telegramApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    query = query || {};
    const options = {
        headers: {},
        method,
        body,
        qs: query,
        uri: `https://api.telegram.org/bot${credentials.accessToken}/${endpoint}`,
        json: true,
    };
    if (Object.keys(option).length > 0) {
        Object.assign(options, option);
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    if (Object.keys(query).length === 0) {
        delete options.qs;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Telegram credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.error_code) {
            const errorBody = error.response.body;
            throw new Error(`Telegram error response [${errorBody.error_code}]: ${errorBody.description}`);
        }
        throw error;
    }
}
exports.apiRequest = apiRequest;
function getImageBySize(photos, size) {
    const sizes = {
        'small': 0,
        'medium': 1,
        'large': 2,
    };
    const index = sizes[size];
    return photos[index];
}
exports.getImageBySize = getImageBySize;
//# sourceMappingURL=GenericFunctions.js.map