"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logFields = exports.logOperations = void 0;
exports.logOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        required: true,
        default: 'getAll',
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: 'Create task log',
            },
            {
                name: 'Execute Responder',
                value: 'executeResponder',
                description: 'Execute a responder on a selected log',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'Get all task logs',
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Get a single log',
            },
        ],
    },
];
exports.logFields = [
    {
        displayName: 'Task ID',
        name: 'taskId',
        type: 'string',
        required: true,
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
                operation: [
                    'create',
                    'getAll',
                ],
            },
        },
        description: 'ID of the task',
    },
    {
        displayName: 'Return All',
        name: 'returnAll',
        type: 'boolean',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'log',
                ],
            },
        },
        default: false,
        description: 'If all results should be returned or only up to a given limit.',
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'log',
                ],
                returnAll: [
                    false,
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 500,
        },
        default: 100,
        description: 'How many results to return.',
    },
    {
        displayName: 'Log ID',
        name: 'id',
        type: 'string',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
                operation: [
                    'executeResponder',
                    'get',
                ],
            },
        },
    },
    {
        displayName: 'Message',
        name: 'message',
        type: 'string',
        required: true,
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
                operation: [
                    'create',
                ],
            },
        },
        description: 'Content of the Log',
    },
    {
        displayName: 'Start Date',
        name: 'startDate',
        type: 'dateTime',
        required: true,
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
                operation: [
                    'create',
                ],
            },
        },
        description: 'Date of the log submission default=now',
    },
    {
        displayName: 'Status',
        name: 'status',
        type: 'options',
        options: [
            {
                name: 'Ok',
                value: 'Ok',
            },
            {
                name: 'Deleted',
                value: 'Deleted',
            },
        ],
        default: '',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
                operation: [
                    'create',
                ],
            },
        },
        description: 'Status of the log (Ok or Deleted) default=Ok',
    },
    {
        displayName: 'Responder ID',
        name: 'responder',
        type: 'options',
        required: true,
        default: '',
        typeOptions: {
            loadOptionsDependsOn: [
                'id',
            ],
            loadOptionsMethod: 'loadResponders',
        },
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
                operation: [
                    'executeResponder',
                ],
            },
            hide: {
                id: [
                    '',
                ],
            },
        },
    },
    {
        displayName: 'Options',
        name: 'options',
        type: 'collection',
        default: {},
        displayOptions: {
            show: {
                resource: [
                    'log',
                ],
                operation: [
                    'create',
                ],
            },
        },
        placeholder: 'Add Option',
        options: [
            {
                displayName: 'Attachment',
                name: 'attachmentValues',
                placeholder: 'Add Attachment',
                type: 'fixedCollection',
                typeOptions: {
                    multipleValues: false,
                },
                default: {},
                options: [
                    {
                        displayName: 'Attachment',
                        name: 'attachmentValues',
                        values: [
                            {
                                displayName: 'Binary Property',
                                name: 'binaryProperty',
                                type: 'string',
                                default: 'data',
                                description: 'Object property name which holds binary data.',
                            },
                        ],
                    },
                ],
                description: 'File attached to the log',
            },
        ],
    },
];
//# sourceMappingURL=LogDescription.js.map