"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.togglApiRequest = void 0;
async function togglApiRequest(method, resource, body = {}, query, uri) {
    const credentials = this.getCredentials('togglApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const headerWithAuthentication = Object.assign({}, { Authorization: ` Basic ${Buffer.from(`${credentials.username}:${credentials.password}`).toString('base64')}` });
    const options = {
        headers: headerWithAuthentication,
        method,
        qs: query,
        uri: uri || `https://www.toggl.com/api/v8${resource}`,
        body,
        json: true,
    };
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 403) {
            throw new Error('The Toggle credentials are probably invalid!');
        }
        const errorMessage = error.response.body && (error.response.body.message || error.response.body.Message);
        if (errorMessage !== undefined) {
            throw new Error(errorMessage);
        }
        throw error;
    }
}
exports.togglApiRequest = togglApiRequest;
//# sourceMappingURL=GenericFunctions.js.map