"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiRequestAllItems = exports.apiRequest = void 0;
async function apiRequest(method, endpoint, body, query) {
    const credentials = this.getCredentials('trelloApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    query = query || {};
    query.key = credentials.apiKey;
    query.token = credentials.apiToken;
    const options = {
        headers: {},
        method,
        body,
        qs: query,
        uri: `https://api.trello.com/1/${endpoint}`,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Trello credentials are not valid!');
        }
        throw error;
    }
}
exports.apiRequest = apiRequest;
async function apiRequestAllItems(method, endpoint, body, query = {}) {
    query.limit = 30;
    query.sort = '-id';
    const returnData = [];
    let responseData;
    do {
        responseData = await apiRequest.call(this, method, endpoint, body, query);
        returnData.push.apply(returnData, responseData);
        if (responseData.length !== 0) {
            query.before = responseData[responseData.length - 1].id;
        }
    } while (query.limit <= responseData.length);
    return returnData;
}
exports.apiRequestAllItems = apiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map