"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.twakeApiRequest = void 0;
async function twakeApiRequest(method, resource, body, query, uri) {
    const authenticationMethod = this.getNodeParameter('twakeVersion', 0, 'twakeCloudApi');
    const options = {
        headers: {},
        method,
        body,
        qs: query,
        uri: uri || `https://connectors.albatros.twakeapp.com/n8n${resource}`,
        json: true,
    };
    const credentials = this.getCredentials('twakeCloudApi');
    options.headers.Authorization = `Bearer ${credentials.workspaceKey}`;
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.error.code === 'ECONNREFUSED') {
            throw new Error('Twake host is not accessible!');
        }
        if (error.statusCode === 401) {
            throw new Error('The Twake credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.errors) {
            const errorMessages = error.response.body.errors.map((errorData) => {
                return errorData.message;
            });
            throw new Error(`Twake error response [${error.statusCode}]: ${errorMessages.join(' | ')}`);
        }
        throw error;
    }
}
exports.twakeApiRequest = twakeApiRequest;
//# sourceMappingURL=GenericFunctions.js.map