"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.twilioApiRequest = void 0;
async function twilioApiRequest(method, endpoint, body, query) {
    const credentials = this.getCredentials('twilioApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    if (query === undefined) {
        query = {};
    }
    const options = {
        method,
        form: body,
        qs: query,
        uri: `https://api.twilio.com/2010-04-01/Accounts/${credentials.accountSid}${endpoint}`,
        auth: {
            user: credentials.accountSid,
            pass: credentials.authToken,
        },
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Twilio credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.message) {
            let errorMessage = `Twilio error response [${error.statusCode}]: ${error.response.body.message}`;
            if (error.response.body.more_info) {
                errorMessage = `errorMessage (${error.response.body.more_info})`;
            }
            throw new Error(errorMessage);
        }
        throw error;
    }
}
exports.twilioApiRequest = twilioApiRequest;
//# sourceMappingURL=GenericFunctions.js.map