"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertNETDates = exports.unleashedApiRequestAllItems = exports.unleashedApiRequest = void 0;
const crypto_1 = require("crypto");
const qs = require("qs");
async function unleashedApiRequest(method, path, body = {}, query = {}, pageNumber, headers) {
    const paginatedPath = pageNumber ? `/${path}/${pageNumber}` : `/${path}`;
    const options = {
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
        },
        method,
        qs: query,
        body,
        url: `https://api.unleashedsoftware.com/${paginatedPath}`,
        json: true,
    };
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    const credentials = this.getCredentials('unleashedSoftwareApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const signature = crypto_1.createHmac('sha256', credentials.apiKey)
        .update(qs.stringify(query))
        .digest('base64');
    options.headers = Object.assign({}, headers, {
        'api-auth-id': credentials.apiId,
        'api-auth-signature': signature,
    });
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.description) {
            throw new Error(`Unleashed Error response [${error.statusCode}]: ${error.response.body.description}`);
        }
        throw error;
    }
}
exports.unleashedApiRequest = unleashedApiRequest;
async function unleashedApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let pageNumber = 1;
    query.pageSize = 1000;
    do {
        responseData = await unleashedApiRequest.call(this, method, endpoint, body, query, pageNumber);
        returnData.push.apply(returnData, responseData[propertyName]);
        pageNumber++;
    } while (responseData.Pagination.PageNumber < responseData.Pagination.NumberOfPages);
    return returnData;
}
exports.unleashedApiRequestAllItems = unleashedApiRequestAllItems;
function convertNETDates(item) {
    Object.keys(item).forEach(path => {
        const type = typeof item[path];
        if (type === 'string') {
            const value = item[path];
            const a = /\/Date\((\d*)\)\//.exec(value);
            if (a) {
                item[path] = new Date(+a[1]);
            }
        }
        if (type === 'object' && item[path]) {
            convertNETDates(item[path]);
        }
    });
}
exports.convertNETDates = convertNETDates;
//# sourceMappingURL=GenericFunctions.js.map