"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toSnakeCase = exports.setMetadata = exports.getAutomaticSecret = exports.woocommerceApiRequestAllItems = exports.woocommerceApiRequest = void 0;
const crypto_1 = require("crypto");
const change_case_1 = require("change-case");
async function woocommerceApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('wooCommerceApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    let options = {
        auth: {
            user: credentials.consumerKey,
            password: credentials.consumerSecret,
        },
        method,
        qs,
        body,
        uri: uri || `${credentials.url}/wp-json/wc/v3${resource}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.form;
    }
    options = Object.assign({}, options, option);
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The WooCommerce credentials are not valid!');
        }
        if (error.response.body && error.response.body.message) {
            throw new Error(`WooCommerce Error [${error.statusCode}]: ${error.response.body.message}`);
        }
        throw new Error('WooCommerce Error: ' + error.message);
    }
}
exports.woocommerceApiRequest = woocommerceApiRequest;
async function woocommerceApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query.per_page = 100;
    do {
        responseData = await woocommerceApiRequest.call(this, method, endpoint, body, query, uri, { resolveWithFullResponse: true });
        uri = responseData.headers['link'].split(';')[0].replace('<', '').replace('>', '');
        returnData.push.apply(returnData, responseData.body);
    } while (responseData.headers['link'] !== undefined &&
        responseData.headers['link'].includes('rel="next"'));
    return returnData;
}
exports.woocommerceApiRequestAllItems = woocommerceApiRequestAllItems;
function getAutomaticSecret(credentials) {
    const data = `${credentials.consumerKey},${credentials.consumerSecret}`;
    return crypto_1.createHash('md5').update(data).digest('hex');
}
exports.getAutomaticSecret = getAutomaticSecret;
function setMetadata(data) {
    for (let i = 0; i < data.length; i++) {
        if (data[i].metadataUi && data[i].metadataUi.metadataValues) {
            data[i].meta_data = data[i].metadataUi.metadataValues;
            delete data[i].metadataUi;
        }
        else {
            delete data[i].metadataUi;
        }
    }
}
exports.setMetadata = setMetadata;
function toSnakeCase(data) {
    if (!Array.isArray(data)) {
        data = [data];
    }
    let remove = false;
    for (let i = 0; i < data.length; i++) {
        for (const key of Object.keys(data[i])) {
            if (data[i][change_case_1.snakeCase(key)] === undefined) {
                remove = true;
            }
            data[i][change_case_1.snakeCase(key)] = data[i][key];
            if (remove) {
                delete data[i][key];
                remove = false;
            }
        }
    }
}
exports.toSnakeCase = toSnakeCase;
//# sourceMappingURL=GenericFunctions.js.map